import subprocess
import re

URL = 'https://eapi.jiasu123.net/bs/bdCoSpeed/deaab7633f2c636410b50f3be3b80f2a8190efa82e9f11141c12efcded2c841ff9f4e2d6ef420479f2200a02704a0393'
SUCCESS_KEYWORDS = ["正在", "成功", "服务"]
PPP_CURL_FILE = '/root/ppp-curl.txt'

def run_curl_task(interface):
    """运行curl任务并检查结果"""
    try:
        print(f"Running curl on interface {interface}...")
        result = subprocess.check_output(['curl', '--interface', interface, URL], stderr=subprocess.STDOUT).decode('utf-8')
        print(f"curl result on {interface}: {result}")
        if any(keyword in result for keyword in SUCCESS_KEYWORDS):
            print(f"Task succeeded on interface {interface}")
            return True
        else:
            print(f"Task failed on interface {interface}, killing process...")
            kill_ppp_process(interface)
            return False
    except subprocess.CalledProcessError as e:
        print(f"Error running curl task on {interface}: {e.output.decode('utf-8')}")
        kill_ppp_process(interface)
        return False

def kill_ppp_process(interface):
    """查询ppp进程并kill"""
    try:
        print(f"Killing process for interface {interface}...")
        # 提取接口编号
        interface_number = interface.lstrip('ppp')
        output = subprocess.check_output(['ps', '-aux']).decode('utf-8')
        lines = output.split('\n')
        for line in lines:
            pattern = re.compile(rf'/usr/sbin/pppd-{interface_number}\b')
            if pattern.search(line) and 'grep' not in line:
                process_id = re.split(r'\s+', line)[1]
                print(f"Found process ID {process_id} for interface {interface}")
                subprocess.run(['kill', '-9', process_id], check=True)
                print(f"Process {process_id} for interface {interface} killed")
                break
        else:
            print(f"No process found for interface {interface}")
    except subprocess.CalledProcessError as e:
        print(f"Error killing process for interface {interface}: {e}")

def main():
    try:
        with open(PPP_CURL_FILE, 'r') as file:
            for line in file:
                interface, ip = line.strip().split()
                if not run_curl_task(interface):
                    print("Curl task failed.")
    except FileNotFoundError:
        print(f"Error: {PPP_CURL_FILE} not found.")

if __name__ == "__main__":
    main()
